# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *
from ._inputs import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_gcp.accessapproval as __accessapproval
    accessapproval = __accessapproval
    import pulumi_gcp.accesscontextmanager as __accesscontextmanager
    accesscontextmanager = __accesscontextmanager
    import pulumi_gcp.activedirectory as __activedirectory
    activedirectory = __activedirectory
    import pulumi_gcp.alloydb as __alloydb
    alloydb = __alloydb
    import pulumi_gcp.apigateway as __apigateway
    apigateway = __apigateway
    import pulumi_gcp.apigee as __apigee
    apigee = __apigee
    import pulumi_gcp.appengine as __appengine
    appengine = __appengine
    import pulumi_gcp.artifactregistry as __artifactregistry
    artifactregistry = __artifactregistry
    import pulumi_gcp.assuredworkloads as __assuredworkloads
    assuredworkloads = __assuredworkloads
    import pulumi_gcp.bigquery as __bigquery
    bigquery = __bigquery
    import pulumi_gcp.bigqueryanalyticshub as __bigqueryanalyticshub
    bigqueryanalyticshub = __bigqueryanalyticshub
    import pulumi_gcp.bigquerydatapolicy as __bigquerydatapolicy
    bigquerydatapolicy = __bigquerydatapolicy
    import pulumi_gcp.bigtable as __bigtable
    bigtable = __bigtable
    import pulumi_gcp.billing as __billing
    billing = __billing
    import pulumi_gcp.binaryauthorization as __binaryauthorization
    binaryauthorization = __binaryauthorization
    import pulumi_gcp.certificateauthority as __certificateauthority
    certificateauthority = __certificateauthority
    import pulumi_gcp.certificatemanager as __certificatemanager
    certificatemanager = __certificatemanager
    import pulumi_gcp.cloudasset as __cloudasset
    cloudasset = __cloudasset
    import pulumi_gcp.cloudbuild as __cloudbuild
    cloudbuild = __cloudbuild
    import pulumi_gcp.clouddeploy as __clouddeploy
    clouddeploy = __clouddeploy
    import pulumi_gcp.cloudfunctions as __cloudfunctions
    cloudfunctions = __cloudfunctions
    import pulumi_gcp.cloudfunctionsv2 as __cloudfunctionsv2
    cloudfunctionsv2 = __cloudfunctionsv2
    import pulumi_gcp.cloudidentity as __cloudidentity
    cloudidentity = __cloudidentity
    import pulumi_gcp.cloudids as __cloudids
    cloudids = __cloudids
    import pulumi_gcp.cloudrun as __cloudrun
    cloudrun = __cloudrun
    import pulumi_gcp.cloudscheduler as __cloudscheduler
    cloudscheduler = __cloudscheduler
    import pulumi_gcp.cloudtasks as __cloudtasks
    cloudtasks = __cloudtasks
    import pulumi_gcp.composer as __composer
    composer = __composer
    import pulumi_gcp.compute as __compute
    compute = __compute
    import pulumi_gcp.config as __config
    config = __config
    import pulumi_gcp.container as __container
    container = __container
    import pulumi_gcp.containeranalysis as __containeranalysis
    containeranalysis = __containeranalysis
    import pulumi_gcp.datacatalog as __datacatalog
    datacatalog = __datacatalog
    import pulumi_gcp.dataflow as __dataflow
    dataflow = __dataflow
    import pulumi_gcp.dataform as __dataform
    dataform = __dataform
    import pulumi_gcp.datafusion as __datafusion
    datafusion = __datafusion
    import pulumi_gcp.dataloss as __dataloss
    dataloss = __dataloss
    import pulumi_gcp.dataplex as __dataplex
    dataplex = __dataplex
    import pulumi_gcp.dataproc as __dataproc
    dataproc = __dataproc
    import pulumi_gcp.datastore as __datastore
    datastore = __datastore
    import pulumi_gcp.datastream as __datastream
    datastream = __datastream
    import pulumi_gcp.deploymentmanager as __deploymentmanager
    deploymentmanager = __deploymentmanager
    import pulumi_gcp.diagflow as __diagflow
    diagflow = __diagflow
    import pulumi_gcp.dns as __dns
    dns = __dns
    import pulumi_gcp.endpoints as __endpoints
    endpoints = __endpoints
    import pulumi_gcp.essentialcontacts as __essentialcontacts
    essentialcontacts = __essentialcontacts
    import pulumi_gcp.eventarc as __eventarc
    eventarc = __eventarc
    import pulumi_gcp.filestore as __filestore
    filestore = __filestore
    import pulumi_gcp.firebase as __firebase
    firebase = __firebase
    import pulumi_gcp.firebaserules as __firebaserules
    firebaserules = __firebaserules
    import pulumi_gcp.firestore as __firestore
    firestore = __firestore
    import pulumi_gcp.folder as __folder
    folder = __folder
    import pulumi_gcp.gameservices as __gameservices
    gameservices = __gameservices
    import pulumi_gcp.gkehub as __gkehub
    gkehub = __gkehub
    import pulumi_gcp.healthcare as __healthcare
    healthcare = __healthcare
    import pulumi_gcp.iam as __iam
    iam = __iam
    import pulumi_gcp.iap as __iap
    iap = __iap
    import pulumi_gcp.identityplatform as __identityplatform
    identityplatform = __identityplatform
    import pulumi_gcp.iot as __iot
    iot = __iot
    import pulumi_gcp.kms as __kms
    kms = __kms
    import pulumi_gcp.logging as __logging
    logging = __logging
    import pulumi_gcp.memcache as __memcache
    memcache = __memcache
    import pulumi_gcp.ml as __ml
    ml = __ml
    import pulumi_gcp.monitoring as __monitoring
    monitoring = __monitoring
    import pulumi_gcp.networkconnectivity as __networkconnectivity
    networkconnectivity = __networkconnectivity
    import pulumi_gcp.networkmanagement as __networkmanagement
    networkmanagement = __networkmanagement
    import pulumi_gcp.networkservices as __networkservices
    networkservices = __networkservices
    import pulumi_gcp.notebooks as __notebooks
    notebooks = __notebooks
    import pulumi_gcp.organizations as __organizations
    organizations = __organizations
    import pulumi_gcp.orgpolicy as __orgpolicy
    orgpolicy = __orgpolicy
    import pulumi_gcp.osconfig as __osconfig
    osconfig = __osconfig
    import pulumi_gcp.oslogin as __oslogin
    oslogin = __oslogin
    import pulumi_gcp.projects as __projects
    projects = __projects
    import pulumi_gcp.pubsub as __pubsub
    pubsub = __pubsub
    import pulumi_gcp.recaptcha as __recaptcha
    recaptcha = __recaptcha
    import pulumi_gcp.redis as __redis
    redis = __redis
    import pulumi_gcp.resourcemanager as __resourcemanager
    resourcemanager = __resourcemanager
    import pulumi_gcp.runtimeconfig as __runtimeconfig
    runtimeconfig = __runtimeconfig
    import pulumi_gcp.secretmanager as __secretmanager
    secretmanager = __secretmanager
    import pulumi_gcp.securitycenter as __securitycenter
    securitycenter = __securitycenter
    import pulumi_gcp.serviceaccount as __serviceaccount
    serviceaccount = __serviceaccount
    import pulumi_gcp.servicedirectory as __servicedirectory
    servicedirectory = __servicedirectory
    import pulumi_gcp.servicenetworking as __servicenetworking
    servicenetworking = __servicenetworking
    import pulumi_gcp.serviceusage as __serviceusage
    serviceusage = __serviceusage
    import pulumi_gcp.sourcerepo as __sourcerepo
    sourcerepo = __sourcerepo
    import pulumi_gcp.spanner as __spanner
    spanner = __spanner
    import pulumi_gcp.sql as __sql
    sql = __sql
    import pulumi_gcp.storage as __storage
    storage = __storage
    import pulumi_gcp.tags as __tags
    tags = __tags
    import pulumi_gcp.tpu as __tpu
    tpu = __tpu
    import pulumi_gcp.vertex as __vertex
    vertex = __vertex
    import pulumi_gcp.vpcaccess as __vpcaccess
    vpcaccess = __vpcaccess
    import pulumi_gcp.workflows as __workflows
    workflows = __workflows
else:
    accessapproval = _utilities.lazy_import('pulumi_gcp.accessapproval')
    accesscontextmanager = _utilities.lazy_import('pulumi_gcp.accesscontextmanager')
    activedirectory = _utilities.lazy_import('pulumi_gcp.activedirectory')
    alloydb = _utilities.lazy_import('pulumi_gcp.alloydb')
    apigateway = _utilities.lazy_import('pulumi_gcp.apigateway')
    apigee = _utilities.lazy_import('pulumi_gcp.apigee')
    appengine = _utilities.lazy_import('pulumi_gcp.appengine')
    artifactregistry = _utilities.lazy_import('pulumi_gcp.artifactregistry')
    assuredworkloads = _utilities.lazy_import('pulumi_gcp.assuredworkloads')
    bigquery = _utilities.lazy_import('pulumi_gcp.bigquery')
    bigqueryanalyticshub = _utilities.lazy_import('pulumi_gcp.bigqueryanalyticshub')
    bigquerydatapolicy = _utilities.lazy_import('pulumi_gcp.bigquerydatapolicy')
    bigtable = _utilities.lazy_import('pulumi_gcp.bigtable')
    billing = _utilities.lazy_import('pulumi_gcp.billing')
    binaryauthorization = _utilities.lazy_import('pulumi_gcp.binaryauthorization')
    certificateauthority = _utilities.lazy_import('pulumi_gcp.certificateauthority')
    certificatemanager = _utilities.lazy_import('pulumi_gcp.certificatemanager')
    cloudasset = _utilities.lazy_import('pulumi_gcp.cloudasset')
    cloudbuild = _utilities.lazy_import('pulumi_gcp.cloudbuild')
    clouddeploy = _utilities.lazy_import('pulumi_gcp.clouddeploy')
    cloudfunctions = _utilities.lazy_import('pulumi_gcp.cloudfunctions')
    cloudfunctionsv2 = _utilities.lazy_import('pulumi_gcp.cloudfunctionsv2')
    cloudidentity = _utilities.lazy_import('pulumi_gcp.cloudidentity')
    cloudids = _utilities.lazy_import('pulumi_gcp.cloudids')
    cloudrun = _utilities.lazy_import('pulumi_gcp.cloudrun')
    cloudscheduler = _utilities.lazy_import('pulumi_gcp.cloudscheduler')
    cloudtasks = _utilities.lazy_import('pulumi_gcp.cloudtasks')
    composer = _utilities.lazy_import('pulumi_gcp.composer')
    compute = _utilities.lazy_import('pulumi_gcp.compute')
    config = _utilities.lazy_import('pulumi_gcp.config')
    container = _utilities.lazy_import('pulumi_gcp.container')
    containeranalysis = _utilities.lazy_import('pulumi_gcp.containeranalysis')
    datacatalog = _utilities.lazy_import('pulumi_gcp.datacatalog')
    dataflow = _utilities.lazy_import('pulumi_gcp.dataflow')
    dataform = _utilities.lazy_import('pulumi_gcp.dataform')
    datafusion = _utilities.lazy_import('pulumi_gcp.datafusion')
    dataloss = _utilities.lazy_import('pulumi_gcp.dataloss')
    dataplex = _utilities.lazy_import('pulumi_gcp.dataplex')
    dataproc = _utilities.lazy_import('pulumi_gcp.dataproc')
    datastore = _utilities.lazy_import('pulumi_gcp.datastore')
    datastream = _utilities.lazy_import('pulumi_gcp.datastream')
    deploymentmanager = _utilities.lazy_import('pulumi_gcp.deploymentmanager')
    diagflow = _utilities.lazy_import('pulumi_gcp.diagflow')
    dns = _utilities.lazy_import('pulumi_gcp.dns')
    endpoints = _utilities.lazy_import('pulumi_gcp.endpoints')
    essentialcontacts = _utilities.lazy_import('pulumi_gcp.essentialcontacts')
    eventarc = _utilities.lazy_import('pulumi_gcp.eventarc')
    filestore = _utilities.lazy_import('pulumi_gcp.filestore')
    firebase = _utilities.lazy_import('pulumi_gcp.firebase')
    firebaserules = _utilities.lazy_import('pulumi_gcp.firebaserules')
    firestore = _utilities.lazy_import('pulumi_gcp.firestore')
    folder = _utilities.lazy_import('pulumi_gcp.folder')
    gameservices = _utilities.lazy_import('pulumi_gcp.gameservices')
    gkehub = _utilities.lazy_import('pulumi_gcp.gkehub')
    healthcare = _utilities.lazy_import('pulumi_gcp.healthcare')
    iam = _utilities.lazy_import('pulumi_gcp.iam')
    iap = _utilities.lazy_import('pulumi_gcp.iap')
    identityplatform = _utilities.lazy_import('pulumi_gcp.identityplatform')
    iot = _utilities.lazy_import('pulumi_gcp.iot')
    kms = _utilities.lazy_import('pulumi_gcp.kms')
    logging = _utilities.lazy_import('pulumi_gcp.logging')
    memcache = _utilities.lazy_import('pulumi_gcp.memcache')
    ml = _utilities.lazy_import('pulumi_gcp.ml')
    monitoring = _utilities.lazy_import('pulumi_gcp.monitoring')
    networkconnectivity = _utilities.lazy_import('pulumi_gcp.networkconnectivity')
    networkmanagement = _utilities.lazy_import('pulumi_gcp.networkmanagement')
    networkservices = _utilities.lazy_import('pulumi_gcp.networkservices')
    notebooks = _utilities.lazy_import('pulumi_gcp.notebooks')
    organizations = _utilities.lazy_import('pulumi_gcp.organizations')
    orgpolicy = _utilities.lazy_import('pulumi_gcp.orgpolicy')
    osconfig = _utilities.lazy_import('pulumi_gcp.osconfig')
    oslogin = _utilities.lazy_import('pulumi_gcp.oslogin')
    projects = _utilities.lazy_import('pulumi_gcp.projects')
    pubsub = _utilities.lazy_import('pulumi_gcp.pubsub')
    recaptcha = _utilities.lazy_import('pulumi_gcp.recaptcha')
    redis = _utilities.lazy_import('pulumi_gcp.redis')
    resourcemanager = _utilities.lazy_import('pulumi_gcp.resourcemanager')
    runtimeconfig = _utilities.lazy_import('pulumi_gcp.runtimeconfig')
    secretmanager = _utilities.lazy_import('pulumi_gcp.secretmanager')
    securitycenter = _utilities.lazy_import('pulumi_gcp.securitycenter')
    serviceaccount = _utilities.lazy_import('pulumi_gcp.serviceaccount')
    servicedirectory = _utilities.lazy_import('pulumi_gcp.servicedirectory')
    servicenetworking = _utilities.lazy_import('pulumi_gcp.servicenetworking')
    serviceusage = _utilities.lazy_import('pulumi_gcp.serviceusage')
    sourcerepo = _utilities.lazy_import('pulumi_gcp.sourcerepo')
    spanner = _utilities.lazy_import('pulumi_gcp.spanner')
    sql = _utilities.lazy_import('pulumi_gcp.sql')
    storage = _utilities.lazy_import('pulumi_gcp.storage')
    tags = _utilities.lazy_import('pulumi_gcp.tags')
    tpu = _utilities.lazy_import('pulumi_gcp.tpu')
    vertex = _utilities.lazy_import('pulumi_gcp.vertex')
    vpcaccess = _utilities.lazy_import('pulumi_gcp.vpcaccess')
    workflows = _utilities.lazy_import('pulumi_gcp.workflows')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessLevel",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessLevel:AccessLevel": "AccessLevel"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessLevelCondition",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessLevelCondition:AccessLevelCondition": "AccessLevelCondition"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessLevels",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessLevels:AccessLevels": "AccessLevels"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessPolicy",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessPolicy:AccessPolicy": "AccessPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessPolicyIamBinding",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessPolicyIamBinding:AccessPolicyIamBinding": "AccessPolicyIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessPolicyIamMember",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessPolicyIamMember:AccessPolicyIamMember": "AccessPolicyIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/accessPolicyIamPolicy",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/accessPolicyIamPolicy:AccessPolicyIamPolicy": "AccessPolicyIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/gcpUserAccessBinding",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/gcpUserAccessBinding:GcpUserAccessBinding": "GcpUserAccessBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/servicePerimeter",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/servicePerimeter:ServicePerimeter": "ServicePerimeter"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/servicePerimeterResource",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/servicePerimeterResource:ServicePerimeterResource": "ServicePerimeterResource"
  }
 },
 {
  "pkg": "gcp",
  "mod": "accesscontextmanager/servicePerimeters",
  "fqn": "pulumi_gcp.accesscontextmanager",
  "classes": {
   "gcp:accesscontextmanager/servicePerimeters:ServicePerimeters": "ServicePerimeters"
  }
 },
 {
  "pkg": "gcp",
  "mod": "activedirectory/domain",
  "fqn": "pulumi_gcp.activedirectory",
  "classes": {
   "gcp:activedirectory/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "gcp",
  "mod": "activedirectory/domainTrust",
  "fqn": "pulumi_gcp.activedirectory",
  "classes": {
   "gcp:activedirectory/domainTrust:DomainTrust": "DomainTrust"
  }
 },
 {
  "pkg": "gcp",
  "mod": "activedirectory/peering",
  "fqn": "pulumi_gcp.activedirectory",
  "classes": {
   "gcp:activedirectory/peering:Peering": "Peering"
  }
 },
 {
  "pkg": "gcp",
  "mod": "alloydb/cluster",
  "fqn": "pulumi_gcp.alloydb",
  "classes": {
   "gcp:alloydb/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/api",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/api:Api": "Api"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiConfig",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiConfig:ApiConfig": "ApiConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiConfigIamBinding",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiConfigIamBinding:ApiConfigIamBinding": "ApiConfigIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiConfigIamMember",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiConfigIamMember:ApiConfigIamMember": "ApiConfigIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiConfigIamPolicy",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiConfigIamPolicy:ApiConfigIamPolicy": "ApiConfigIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiIamBinding",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiIamBinding:ApiIamBinding": "ApiIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiIamMember",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiIamMember:ApiIamMember": "ApiIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/apiIamPolicy",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/apiIamPolicy:ApiIamPolicy": "ApiIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/gateway",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/gatewayIamBinding",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/gatewayIamBinding:GatewayIamBinding": "GatewayIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/gatewayIamMember",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/gatewayIamMember:GatewayIamMember": "GatewayIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigateway/gatewayIamPolicy",
  "fqn": "pulumi_gcp.apigateway",
  "classes": {
   "gcp:apigateway/gatewayIamPolicy:GatewayIamPolicy": "GatewayIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/endpointAttachment",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/endpointAttachment:EndpointAttachment": "EndpointAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/envGroup",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/envGroup:EnvGroup": "EnvGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/envGroupAttachment",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/envGroupAttachment:EnvGroupAttachment": "EnvGroupAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/environment",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/environmentIamBinding",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/environmentIamBinding:EnvironmentIamBinding": "EnvironmentIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/environmentIamMember",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/environmentIamMember:EnvironmentIamMember": "EnvironmentIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/environmentIamPolicy",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/environmentIamPolicy:EnvironmentIamPolicy": "EnvironmentIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/instance",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/instanceAttachment",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/instanceAttachment:InstanceAttachment": "InstanceAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/natAddress",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/natAddress:NatAddress": "NatAddress"
  }
 },
 {
  "pkg": "gcp",
  "mod": "apigee/organization",
  "fqn": "pulumi_gcp.apigee",
  "classes": {
   "gcp:apigee/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/application",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/application:Application": "Application"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/applicationUrlDispatchRules",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/applicationUrlDispatchRules:ApplicationUrlDispatchRules": "ApplicationUrlDispatchRules"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/domainMapping",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/domainMapping:DomainMapping": "DomainMapping"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/engineSplitTraffic",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/engineSplitTraffic:EngineSplitTraffic": "EngineSplitTraffic"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/firewallRule",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/flexibleAppVersion",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/flexibleAppVersion:FlexibleAppVersion": "FlexibleAppVersion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/serviceNetworkSettings",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/serviceNetworkSettings:ServiceNetworkSettings": "ServiceNetworkSettings"
  }
 },
 {
  "pkg": "gcp",
  "mod": "appengine/standardAppVersion",
  "fqn": "pulumi_gcp.appengine",
  "classes": {
   "gcp:appengine/standardAppVersion:StandardAppVersion": "StandardAppVersion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "artifactregistry/repository",
  "fqn": "pulumi_gcp.artifactregistry",
  "classes": {
   "gcp:artifactregistry/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "gcp",
  "mod": "artifactregistry/repositoryIamBinding",
  "fqn": "pulumi_gcp.artifactregistry",
  "classes": {
   "gcp:artifactregistry/repositoryIamBinding:RepositoryIamBinding": "RepositoryIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "artifactregistry/repositoryIamMember",
  "fqn": "pulumi_gcp.artifactregistry",
  "classes": {
   "gcp:artifactregistry/repositoryIamMember:RepositoryIamMember": "RepositoryIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "artifactregistry/repositoryIamPolicy",
  "fqn": "pulumi_gcp.artifactregistry",
  "classes": {
   "gcp:artifactregistry/repositoryIamPolicy:RepositoryIamPolicy": "RepositoryIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "assuredworkloads/workload",
  "fqn": "pulumi_gcp.assuredworkloads",
  "classes": {
   "gcp:assuredworkloads/workload:Workload": "Workload"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/appProfile",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/appProfile:AppProfile": "AppProfile"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/connection",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/connectionIamBinding",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/connectionIamBinding:ConnectionIamBinding": "ConnectionIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/connectionIamMember",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/connectionIamMember:ConnectionIamMember": "ConnectionIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/connectionIamPolicy",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/connectionIamPolicy:ConnectionIamPolicy": "ConnectionIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/dataTransferConfig",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/dataTransferConfig:DataTransferConfig": "DataTransferConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/dataset",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/dataset:Dataset": "Dataset"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/datasetAccess",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/datasetAccess:DatasetAccess": "DatasetAccess"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/datasetIamBinding",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/datasetIamBinding:DatasetIamBinding": "DatasetIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/datasetIamMember",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/datasetIamMember:DatasetIamMember": "DatasetIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/datasetIamPolicy",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/datasetIamPolicy:DatasetIamPolicy": "DatasetIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/iamBinding",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/iamBinding:IamBinding": "IamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/iamMember",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/iamMember:IamMember": "IamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/iamPolicy",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/iamPolicy:IamPolicy": "IamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/job",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/job:Job": "Job"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/reservation",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/reservation:Reservation": "Reservation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/reservationAssignment",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/reservationAssignment:ReservationAssignment": "ReservationAssignment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/routine",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/routine:Routine": "Routine"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquery/table",
  "fqn": "pulumi_gcp.bigquery",
  "classes": {
   "gcp:bigquery/table:Table": "Table"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/dataExchange",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/dataExchange:DataExchange": "DataExchange"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/dataExchangeIamBinding",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/dataExchangeIamBinding:DataExchangeIamBinding": "DataExchangeIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/dataExchangeIamMember",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/dataExchangeIamMember:DataExchangeIamMember": "DataExchangeIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/dataExchangeIamPolicy",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/dataExchangeIamPolicy:DataExchangeIamPolicy": "DataExchangeIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/listing",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/listing:Listing": "Listing"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/listingIamBinding",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/listingIamBinding:ListingIamBinding": "ListingIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/listingIamMember",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/listingIamMember:ListingIamMember": "ListingIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigqueryanalyticshub/listingIamPolicy",
  "fqn": "pulumi_gcp.bigqueryanalyticshub",
  "classes": {
   "gcp:bigqueryanalyticshub/listingIamPolicy:ListingIamPolicy": "ListingIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquerydatapolicy/dataPolicy",
  "fqn": "pulumi_gcp.bigquerydatapolicy",
  "classes": {
   "gcp:bigquerydatapolicy/dataPolicy:DataPolicy": "DataPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquerydatapolicy/dataPolicyIamBinding",
  "fqn": "pulumi_gcp.bigquerydatapolicy",
  "classes": {
   "gcp:bigquerydatapolicy/dataPolicyIamBinding:DataPolicyIamBinding": "DataPolicyIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquerydatapolicy/dataPolicyIamMember",
  "fqn": "pulumi_gcp.bigquerydatapolicy",
  "classes": {
   "gcp:bigquerydatapolicy/dataPolicyIamMember:DataPolicyIamMember": "DataPolicyIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigquerydatapolicy/dataPolicyIamPolicy",
  "fqn": "pulumi_gcp.bigquerydatapolicy",
  "classes": {
   "gcp:bigquerydatapolicy/dataPolicyIamPolicy:DataPolicyIamPolicy": "DataPolicyIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/gCPolicy",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/gCPolicy:GCPolicy": "GCPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/instance",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/instanceIamBinding",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/instanceIamBinding:InstanceIamBinding": "InstanceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/instanceIamMember",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/instanceIamMember:InstanceIamMember": "InstanceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/instanceIamPolicy",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/instanceIamPolicy:InstanceIamPolicy": "InstanceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/table",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/table:Table": "Table"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/tableIamBinding",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/tableIamBinding:TableIamBinding": "TableIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/tableIamMember",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/tableIamMember:TableIamMember": "TableIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "bigtable/tableIamPolicy",
  "fqn": "pulumi_gcp.bigtable",
  "classes": {
   "gcp:bigtable/tableIamPolicy:TableIamPolicy": "TableIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "billing/accountIamBinding",
  "fqn": "pulumi_gcp.billing",
  "classes": {
   "gcp:billing/accountIamBinding:AccountIamBinding": "AccountIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "billing/accountIamMember",
  "fqn": "pulumi_gcp.billing",
  "classes": {
   "gcp:billing/accountIamMember:AccountIamMember": "AccountIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "billing/accountIamPolicy",
  "fqn": "pulumi_gcp.billing",
  "classes": {
   "gcp:billing/accountIamPolicy:AccountIamPolicy": "AccountIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "billing/budget",
  "fqn": "pulumi_gcp.billing",
  "classes": {
   "gcp:billing/budget:Budget": "Budget"
  }
 },
 {
  "pkg": "gcp",
  "mod": "billing/subAccount",
  "fqn": "pulumi_gcp.billing",
  "classes": {
   "gcp:billing/subAccount:SubAccount": "SubAccount"
  }
 },
 {
  "pkg": "gcp",
  "mod": "binaryauthorization/attestor",
  "fqn": "pulumi_gcp.binaryauthorization",
  "classes": {
   "gcp:binaryauthorization/attestor:Attestor": "Attestor"
  }
 },
 {
  "pkg": "gcp",
  "mod": "binaryauthorization/attestorIamBinding",
  "fqn": "pulumi_gcp.binaryauthorization",
  "classes": {
   "gcp:binaryauthorization/attestorIamBinding:AttestorIamBinding": "AttestorIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "binaryauthorization/attestorIamMember",
  "fqn": "pulumi_gcp.binaryauthorization",
  "classes": {
   "gcp:binaryauthorization/attestorIamMember:AttestorIamMember": "AttestorIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "binaryauthorization/attestorIamPolicy",
  "fqn": "pulumi_gcp.binaryauthorization",
  "classes": {
   "gcp:binaryauthorization/attestorIamPolicy:AttestorIamPolicy": "AttestorIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "binaryauthorization/policy",
  "fqn": "pulumi_gcp.binaryauthorization",
  "classes": {
   "gcp:binaryauthorization/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/authority",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/authority:Authority": "Authority"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/caPool",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/caPool:CaPool": "CaPool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/caPoolIamBinding",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/caPoolIamBinding:CaPoolIamBinding": "CaPoolIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/caPoolIamMember",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/caPoolIamMember:CaPoolIamMember": "CaPoolIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/caPoolIamPolicy",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/caPoolIamPolicy:CaPoolIamPolicy": "CaPoolIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/certificate",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/certificateTemplate",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/certificateTemplate:CertificateTemplate": "CertificateTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/certificateTemplateIamBinding",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/certificateTemplateIamBinding:CertificateTemplateIamBinding": "CertificateTemplateIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/certificateTemplateIamMember",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/certificateTemplateIamMember:CertificateTemplateIamMember": "CertificateTemplateIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificateauthority/certificateTemplateIamPolicy",
  "fqn": "pulumi_gcp.certificateauthority",
  "classes": {
   "gcp:certificateauthority/certificateTemplateIamPolicy:CertificateTemplateIamPolicy": "CertificateTemplateIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificatemanager/certificate",
  "fqn": "pulumi_gcp.certificatemanager",
  "classes": {
   "gcp:certificatemanager/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificatemanager/certificateMap",
  "fqn": "pulumi_gcp.certificatemanager",
  "classes": {
   "gcp:certificatemanager/certificateMap:CertificateMap": "CertificateMap"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificatemanager/certificateMapEntry",
  "fqn": "pulumi_gcp.certificatemanager",
  "classes": {
   "gcp:certificatemanager/certificateMapEntry:CertificateMapEntry": "CertificateMapEntry"
  }
 },
 {
  "pkg": "gcp",
  "mod": "certificatemanager/dnsAuthorization",
  "fqn": "pulumi_gcp.certificatemanager",
  "classes": {
   "gcp:certificatemanager/dnsAuthorization:DnsAuthorization": "DnsAuthorization"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudasset/folderFeed",
  "fqn": "pulumi_gcp.cloudasset",
  "classes": {
   "gcp:cloudasset/folderFeed:FolderFeed": "FolderFeed"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudasset/organizationFeed",
  "fqn": "pulumi_gcp.cloudasset",
  "classes": {
   "gcp:cloudasset/organizationFeed:OrganizationFeed": "OrganizationFeed"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudasset/projectFeed",
  "fqn": "pulumi_gcp.cloudasset",
  "classes": {
   "gcp:cloudasset/projectFeed:ProjectFeed": "ProjectFeed"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudbuild/trigger",
  "fqn": "pulumi_gcp.cloudbuild",
  "classes": {
   "gcp:cloudbuild/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudbuild/workerPool",
  "fqn": "pulumi_gcp.cloudbuild",
  "classes": {
   "gcp:cloudbuild/workerPool:WorkerPool": "WorkerPool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "clouddeploy/deliveryPipeline",
  "fqn": "pulumi_gcp.clouddeploy",
  "classes": {
   "gcp:clouddeploy/deliveryPipeline:DeliveryPipeline": "DeliveryPipeline"
  }
 },
 {
  "pkg": "gcp",
  "mod": "clouddeploy/target",
  "fqn": "pulumi_gcp.clouddeploy",
  "classes": {
   "gcp:clouddeploy/target:Target": "Target"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctions/function",
  "fqn": "pulumi_gcp.cloudfunctions",
  "classes": {
   "gcp:cloudfunctions/function:Function": "Function"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctions/functionIamBinding",
  "fqn": "pulumi_gcp.cloudfunctions",
  "classes": {
   "gcp:cloudfunctions/functionIamBinding:FunctionIamBinding": "FunctionIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctions/functionIamMember",
  "fqn": "pulumi_gcp.cloudfunctions",
  "classes": {
   "gcp:cloudfunctions/functionIamMember:FunctionIamMember": "FunctionIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctions/functionIamPolicy",
  "fqn": "pulumi_gcp.cloudfunctions",
  "classes": {
   "gcp:cloudfunctions/functionIamPolicy:FunctionIamPolicy": "FunctionIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctionsv2/function",
  "fqn": "pulumi_gcp.cloudfunctionsv2",
  "classes": {
   "gcp:cloudfunctionsv2/function:Function": "Function"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctionsv2/functionIamBinding",
  "fqn": "pulumi_gcp.cloudfunctionsv2",
  "classes": {
   "gcp:cloudfunctionsv2/functionIamBinding:FunctionIamBinding": "FunctionIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctionsv2/functionIamMember",
  "fqn": "pulumi_gcp.cloudfunctionsv2",
  "classes": {
   "gcp:cloudfunctionsv2/functionIamMember:FunctionIamMember": "FunctionIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudfunctionsv2/functionIamPolicy",
  "fqn": "pulumi_gcp.cloudfunctionsv2",
  "classes": {
   "gcp:cloudfunctionsv2/functionIamPolicy:FunctionIamPolicy": "FunctionIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudidentity/group",
  "fqn": "pulumi_gcp.cloudidentity",
  "classes": {
   "gcp:cloudidentity/group:Group": "Group"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudidentity/groupMembership",
  "fqn": "pulumi_gcp.cloudidentity",
  "classes": {
   "gcp:cloudidentity/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudids/endpoint",
  "fqn": "pulumi_gcp.cloudids",
  "classes": {
   "gcp:cloudids/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudrun/domainMapping",
  "fqn": "pulumi_gcp.cloudrun",
  "classes": {
   "gcp:cloudrun/domainMapping:DomainMapping": "DomainMapping"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudrun/iamBinding",
  "fqn": "pulumi_gcp.cloudrun",
  "classes": {
   "gcp:cloudrun/iamBinding:IamBinding": "IamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudrun/iamMember",
  "fqn": "pulumi_gcp.cloudrun",
  "classes": {
   "gcp:cloudrun/iamMember:IamMember": "IamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudrun/iamPolicy",
  "fqn": "pulumi_gcp.cloudrun",
  "classes": {
   "gcp:cloudrun/iamPolicy:IamPolicy": "IamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudrun/service",
  "fqn": "pulumi_gcp.cloudrun",
  "classes": {
   "gcp:cloudrun/service:Service": "Service"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudscheduler/job",
  "fqn": "pulumi_gcp.cloudscheduler",
  "classes": {
   "gcp:cloudscheduler/job:Job": "Job"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudtasks/queue",
  "fqn": "pulumi_gcp.cloudtasks",
  "classes": {
   "gcp:cloudtasks/queue:Queue": "Queue"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudtasks/queueIamBinding",
  "fqn": "pulumi_gcp.cloudtasks",
  "classes": {
   "gcp:cloudtasks/queueIamBinding:QueueIamBinding": "QueueIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudtasks/queueIamMember",
  "fqn": "pulumi_gcp.cloudtasks",
  "classes": {
   "gcp:cloudtasks/queueIamMember:QueueIamMember": "QueueIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "cloudtasks/queueIamPolicy",
  "fqn": "pulumi_gcp.cloudtasks",
  "classes": {
   "gcp:cloudtasks/queueIamPolicy:QueueIamPolicy": "QueueIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "composer/environment",
  "fqn": "pulumi_gcp.composer",
  "classes": {
   "gcp:composer/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/address",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/address:Address": "Address"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/attachedDisk",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/attachedDisk:AttachedDisk": "AttachedDisk"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/autoscalar",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/autoscalar:Autoscalar": "Autoscalar"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/autoscaler",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/autoscaler:Autoscaler": "Autoscaler"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendBucket",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendBucket:BackendBucket": "BackendBucket"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendBucketIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendBucketIamBinding:BackendBucketIamBinding": "BackendBucketIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendBucketIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendBucketIamMember:BackendBucketIamMember": "BackendBucketIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendBucketIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendBucketIamPolicy:BackendBucketIamPolicy": "BackendBucketIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendBucketSignedUrlKey",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendBucketSignedUrlKey:BackendBucketSignedUrlKey": "BackendBucketSignedUrlKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendService",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendService:BackendService": "BackendService"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendServiceIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendServiceIamBinding:BackendServiceIamBinding": "BackendServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendServiceIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendServiceIamMember:BackendServiceIamMember": "BackendServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendServiceIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendServiceIamPolicy:BackendServiceIamPolicy": "BackendServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/backendServiceSignedUrlKey",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/backendServiceSignedUrlKey:BackendServiceSignedUrlKey": "BackendServiceSignedUrlKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/disk",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/disk:Disk": "Disk"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/diskIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/diskIamBinding:DiskIamBinding": "DiskIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/diskIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/diskIamMember:DiskIamMember": "DiskIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/diskIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/diskIamPolicy:DiskIamPolicy": "DiskIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/diskResourcePolicyAttachment",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/diskResourcePolicyAttachment:DiskResourcePolicyAttachment": "DiskResourcePolicyAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/externalVpnGateway",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/externalVpnGateway:ExternalVpnGateway": "ExternalVpnGateway"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/firewall",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/firewallPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/firewallPolicy:FirewallPolicy": "FirewallPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/firewallPolicyAssociation",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/firewallPolicyAssociation:FirewallPolicyAssociation": "FirewallPolicyAssociation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/firewallPolicyRule",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/firewallPolicyRule:FirewallPolicyRule": "FirewallPolicyRule"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/forwardingRule",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/forwardingRule:ForwardingRule": "ForwardingRule"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/globalAddress",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/globalAddress:GlobalAddress": "GlobalAddress"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/globalForwardingRule",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/globalForwardingRule:GlobalForwardingRule": "GlobalForwardingRule"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/globalNetworkEndpoint",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/globalNetworkEndpoint:GlobalNetworkEndpoint": "GlobalNetworkEndpoint"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/globalNetworkEndpointGroup",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/globalNetworkEndpointGroup:GlobalNetworkEndpointGroup": "GlobalNetworkEndpointGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/haVpnGateway",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/haVpnGateway:HaVpnGateway": "HaVpnGateway"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/healthCheck",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/healthCheck:HealthCheck": "HealthCheck"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/httpHealthCheck",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/httpHealthCheck:HttpHealthCheck": "HttpHealthCheck"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/httpsHealthCheck",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/httpsHealthCheck:HttpsHealthCheck": "HttpsHealthCheck"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/image",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/image:Image": "Image"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/imageIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/imageIamBinding:ImageIamBinding": "ImageIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/imageIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/imageIamMember:ImageIamMember": "ImageIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/imageIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/imageIamPolicy:ImageIamPolicy": "ImageIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instance",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceFromMachineImage",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceFromMachineImage:InstanceFromMachineImage": "InstanceFromMachineImage"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceFromTemplate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceFromTemplate:InstanceFromTemplate": "InstanceFromTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceGroup",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceGroup:InstanceGroup": "InstanceGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceGroupManager",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceGroupManager:InstanceGroupManager": "InstanceGroupManager"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceGroupNamedPort",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceGroupNamedPort:InstanceGroupNamedPort": "InstanceGroupNamedPort"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceIAMBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceIAMBinding:InstanceIAMBinding": "InstanceIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceIAMMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceIAMMember:InstanceIAMMember": "InstanceIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceIAMPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceIAMPolicy:InstanceIAMPolicy": "InstanceIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/instanceTemplate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/instanceTemplate:InstanceTemplate": "InstanceTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/interconnectAttachment",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/interconnectAttachment:InterconnectAttachment": "InterconnectAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/machineImage",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/machineImage:MachineImage": "MachineImage"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/machineImageIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/machineImageIamBinding:MachineImageIamBinding": "MachineImageIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/machineImageIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/machineImageIamMember:MachineImageIamMember": "MachineImageIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/machineImageIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/machineImageIamPolicy:MachineImageIamPolicy": "MachineImageIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/managedSslCertificate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/managedSslCertificate:ManagedSslCertificate": "ManagedSslCertificate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/mangedSslCertificate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/mangedSslCertificate:MangedSslCertificate": "MangedSslCertificate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/network",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/network:Network": "Network"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/networkEndpoint",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/networkEndpoint:NetworkEndpoint": "NetworkEndpoint"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/networkEndpointGroup",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/networkEndpointGroup:NetworkEndpointGroup": "NetworkEndpointGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/networkPeering",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/networkPeering:NetworkPeering": "NetworkPeering"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/networkPeeringRoutesConfig",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/networkPeeringRoutesConfig:NetworkPeeringRoutesConfig": "NetworkPeeringRoutesConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/nodeGroup",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/nodeGroup:NodeGroup": "NodeGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/nodeTemplate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/nodeTemplate:NodeTemplate": "NodeTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/organizationSecurityPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/organizationSecurityPolicy:OrganizationSecurityPolicy": "OrganizationSecurityPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/organizationSecurityPolicyAssociation",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/organizationSecurityPolicyAssociation:OrganizationSecurityPolicyAssociation": "OrganizationSecurityPolicyAssociation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/organizationSecurityPolicyRule",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/organizationSecurityPolicyRule:OrganizationSecurityPolicyRule": "OrganizationSecurityPolicyRule"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/packetMirroring",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/packetMirroring:PacketMirroring": "PacketMirroring"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/perInstanceConfig",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/perInstanceConfig:PerInstanceConfig": "PerInstanceConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/projectDefaultNetworkTier",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/projectDefaultNetworkTier:ProjectDefaultNetworkTier": "ProjectDefaultNetworkTier"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/projectMetadata",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/projectMetadata:ProjectMetadata": "ProjectMetadata"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/projectMetadataItem",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/projectMetadataItem:ProjectMetadataItem": "ProjectMetadataItem"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionAutoscaler",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionAutoscaler:RegionAutoscaler": "RegionAutoscaler"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionBackendService",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionBackendService:RegionBackendService": "RegionBackendService"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionBackendServiceIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionBackendServiceIamBinding:RegionBackendServiceIamBinding": "RegionBackendServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionBackendServiceIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionBackendServiceIamMember:RegionBackendServiceIamMember": "RegionBackendServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionBackendServiceIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionBackendServiceIamPolicy:RegionBackendServiceIamPolicy": "RegionBackendServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionDisk",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionDisk:RegionDisk": "RegionDisk"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionDiskIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionDiskIamBinding:RegionDiskIamBinding": "RegionDiskIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionDiskIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionDiskIamMember:RegionDiskIamMember": "RegionDiskIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionDiskIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionDiskIamPolicy:RegionDiskIamPolicy": "RegionDiskIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionDiskResourcePolicyAttachment",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionDiskResourcePolicyAttachment:RegionDiskResourcePolicyAttachment": "RegionDiskResourcePolicyAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionHealthCheck",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionHealthCheck:RegionHealthCheck": "RegionHealthCheck"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionInstanceGroupManager",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionInstanceGroupManager:RegionInstanceGroupManager": "RegionInstanceGroupManager"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionNetworkEndpointGroup",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionNetworkEndpointGroup:RegionNetworkEndpointGroup": "RegionNetworkEndpointGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionPerInstanceConfig",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionPerInstanceConfig:RegionPerInstanceConfig": "RegionPerInstanceConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionSslCertificate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionSslCertificate:RegionSslCertificate": "RegionSslCertificate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionSslPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionSslPolicy:RegionSslPolicy": "RegionSslPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionTargetHttpProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionTargetHttpProxy:RegionTargetHttpProxy": "RegionTargetHttpProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionTargetHttpsProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionTargetHttpsProxy:RegionTargetHttpsProxy": "RegionTargetHttpsProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionTargetTcpProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionTargetTcpProxy:RegionTargetTcpProxy": "RegionTargetTcpProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/regionUrlMap",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/regionUrlMap:RegionUrlMap": "RegionUrlMap"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/reservation",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/reservation:Reservation": "Reservation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/resourcePolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/resourcePolicy:ResourcePolicy": "ResourcePolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/route",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/route:Route": "Route"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/router",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/router:Router": "Router"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/routerInterface",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/routerInterface:RouterInterface": "RouterInterface"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/routerNat",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/routerNat:RouterNat": "RouterNat"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/routerPeer",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/routerPeer:RouterPeer": "RouterPeer"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/sSLCertificate",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/sSLCertificate:SSLCertificate": "SSLCertificate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/sSLPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/sSLPolicy:SSLPolicy": "SSLPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/securityPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/securityPolicy:SecurityPolicy": "SecurityPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/securityScanConfig",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/securityScanConfig:SecurityScanConfig": "SecurityScanConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/serviceAttachment",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/serviceAttachment:ServiceAttachment": "ServiceAttachment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/sharedVPCHostProject",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/sharedVPCHostProject:SharedVPCHostProject": "SharedVPCHostProject"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/sharedVPCServiceProject",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/sharedVPCServiceProject:SharedVPCServiceProject": "SharedVPCServiceProject"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/snapshot",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/snapshotIamBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/snapshotIamBinding:SnapshotIamBinding": "SnapshotIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/snapshotIamMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/snapshotIamMember:SnapshotIamMember": "SnapshotIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/snapshotIamPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/snapshotIamPolicy:SnapshotIamPolicy": "SnapshotIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/subnetwork",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/subnetwork:Subnetwork": "Subnetwork"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/subnetworkIAMBinding",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/subnetworkIAMBinding:SubnetworkIAMBinding": "SubnetworkIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/subnetworkIAMMember",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/subnetworkIAMMember:SubnetworkIAMMember": "SubnetworkIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/subnetworkIAMPolicy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/subnetworkIAMPolicy:SubnetworkIAMPolicy": "SubnetworkIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetGrpcProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetGrpcProxy:TargetGrpcProxy": "TargetGrpcProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetHttpProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetHttpProxy:TargetHttpProxy": "TargetHttpProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetHttpsProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetHttpsProxy:TargetHttpsProxy": "TargetHttpsProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetInstance",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetInstance:TargetInstance": "TargetInstance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetPool",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetPool:TargetPool": "TargetPool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetSSLProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetSSLProxy:TargetSSLProxy": "TargetSSLProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/targetTCPProxy",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/targetTCPProxy:TargetTCPProxy": "TargetTCPProxy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/uRLMap",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/uRLMap:URLMap": "URLMap"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/vPNGateway",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/vPNGateway:VPNGateway": "VPNGateway"
  }
 },
 {
  "pkg": "gcp",
  "mod": "compute/vPNTunnel",
  "fqn": "pulumi_gcp.compute",
  "classes": {
   "gcp:compute/vPNTunnel:VPNTunnel": "VPNTunnel"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/awsCluster",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/awsCluster:AwsCluster": "AwsCluster"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/awsNodePool",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/awsNodePool:AwsNodePool": "AwsNodePool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/azureClient",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/azureClient:AzureClient": "AzureClient"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/azureCluster",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/azureCluster:AzureCluster": "AzureCluster"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/azureNodePool",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/azureNodePool:AzureNodePool": "AzureNodePool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/cluster",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/nodePool",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/nodePool:NodePool": "NodePool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "container/registry",
  "fqn": "pulumi_gcp.container",
  "classes": {
   "gcp:container/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "gcp",
  "mod": "containeranalysis/note",
  "fqn": "pulumi_gcp.containeranalysis",
  "classes": {
   "gcp:containeranalysis/note:Note": "Note"
  }
 },
 {
  "pkg": "gcp",
  "mod": "containeranalysis/occurence",
  "fqn": "pulumi_gcp.containeranalysis",
  "classes": {
   "gcp:containeranalysis/occurence:Occurence": "Occurence"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/entry",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/entry:Entry": "Entry"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/entryGroup",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/entryGroup:EntryGroup": "EntryGroup"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/entryGroupIamBinding",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/entryGroupIamBinding:EntryGroupIamBinding": "EntryGroupIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/entryGroupIamMember",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/entryGroupIamMember:EntryGroupIamMember": "EntryGroupIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/entryGroupIamPolicy",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/entryGroupIamPolicy:EntryGroupIamPolicy": "EntryGroupIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/policyTag",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/policyTag:PolicyTag": "PolicyTag"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/policyTagIamBinding",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/policyTagIamBinding:PolicyTagIamBinding": "PolicyTagIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/policyTagIamMember",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/policyTagIamMember:PolicyTagIamMember": "PolicyTagIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/policyTagIamPolicy",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/policyTagIamPolicy:PolicyTagIamPolicy": "PolicyTagIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/tag",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/tagTemplate",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/tagTemplate:TagTemplate": "TagTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/tagTemplateIamBinding",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/tagTemplateIamBinding:TagTemplateIamBinding": "TagTemplateIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/tagTemplateIamMember",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/tagTemplateIamMember:TagTemplateIamMember": "TagTemplateIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/tagTemplateIamPolicy",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/tagTemplateIamPolicy:TagTemplateIamPolicy": "TagTemplateIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/taxonomy",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/taxonomy:Taxonomy": "Taxonomy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/taxonomyIamBinding",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/taxonomyIamBinding:TaxonomyIamBinding": "TaxonomyIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/taxonomyIamMember",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/taxonomyIamMember:TaxonomyIamMember": "TaxonomyIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datacatalog/taxonomyIamPolicy",
  "fqn": "pulumi_gcp.datacatalog",
  "classes": {
   "gcp:datacatalog/taxonomyIamPolicy:TaxonomyIamPolicy": "TaxonomyIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataflow/flexTemplateJob",
  "fqn": "pulumi_gcp.dataflow",
  "classes": {
   "gcp:dataflow/flexTemplateJob:FlexTemplateJob": "FlexTemplateJob"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataflow/job",
  "fqn": "pulumi_gcp.dataflow",
  "classes": {
   "gcp:dataflow/job:Job": "Job"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataform/repository",
  "fqn": "pulumi_gcp.dataform",
  "classes": {
   "gcp:dataform/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datafusion/instance",
  "fqn": "pulumi_gcp.datafusion",
  "classes": {
   "gcp:datafusion/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataloss/preventionDeidentifyTemplate",
  "fqn": "pulumi_gcp.dataloss",
  "classes": {
   "gcp:dataloss/preventionDeidentifyTemplate:PreventionDeidentifyTemplate": "PreventionDeidentifyTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataloss/preventionInspectTemplate",
  "fqn": "pulumi_gcp.dataloss",
  "classes": {
   "gcp:dataloss/preventionInspectTemplate:PreventionInspectTemplate": "PreventionInspectTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataloss/preventionJobTrigger",
  "fqn": "pulumi_gcp.dataloss",
  "classes": {
   "gcp:dataloss/preventionJobTrigger:PreventionJobTrigger": "PreventionJobTrigger"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataloss/preventionStoredInfoType",
  "fqn": "pulumi_gcp.dataloss",
  "classes": {
   "gcp:dataloss/preventionStoredInfoType:PreventionStoredInfoType": "PreventionStoredInfoType"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataplex/asset",
  "fqn": "pulumi_gcp.dataplex",
  "classes": {
   "gcp:dataplex/asset:Asset": "Asset"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataplex/lake",
  "fqn": "pulumi_gcp.dataplex",
  "classes": {
   "gcp:dataplex/lake:Lake": "Lake"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataplex/zone",
  "fqn": "pulumi_gcp.dataplex",
  "classes": {
   "gcp:dataplex/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/autoscalingPolicy",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/autoscalingPolicy:AutoscalingPolicy": "AutoscalingPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/autoscalingPolicyIamBinding",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/autoscalingPolicyIamBinding:AutoscalingPolicyIamBinding": "AutoscalingPolicyIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/autoscalingPolicyIamMember",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/autoscalingPolicyIamMember:AutoscalingPolicyIamMember": "AutoscalingPolicyIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/autoscalingPolicyIamPolicy",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/autoscalingPolicyIamPolicy:AutoscalingPolicyIamPolicy": "AutoscalingPolicyIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/cluster",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/clusterIAMBinding",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/clusterIAMBinding:ClusterIAMBinding": "ClusterIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/clusterIAMMember",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/clusterIAMMember:ClusterIAMMember": "ClusterIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/clusterIAMPolicy",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/clusterIAMPolicy:ClusterIAMPolicy": "ClusterIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/job",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/job:Job": "Job"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/jobIAMBinding",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/jobIAMBinding:JobIAMBinding": "JobIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/jobIAMMember",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/jobIAMMember:JobIAMMember": "JobIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/jobIAMPolicy",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/jobIAMPolicy:JobIAMPolicy": "JobIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreFederation",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreFederation:MetastoreFederation": "MetastoreFederation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreFederationIamBinding",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreFederationIamBinding:MetastoreFederationIamBinding": "MetastoreFederationIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreFederationIamMember",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreFederationIamMember:MetastoreFederationIamMember": "MetastoreFederationIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreFederationIamPolicy",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreFederationIamPolicy:MetastoreFederationIamPolicy": "MetastoreFederationIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreService",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreService:MetastoreService": "MetastoreService"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreServiceIamBinding",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreServiceIamBinding:MetastoreServiceIamBinding": "MetastoreServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreServiceIamMember",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreServiceIamMember:MetastoreServiceIamMember": "MetastoreServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/metastoreServiceIamPolicy",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/metastoreServiceIamPolicy:MetastoreServiceIamPolicy": "MetastoreServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dataproc/workflowTemplate",
  "fqn": "pulumi_gcp.dataproc",
  "classes": {
   "gcp:dataproc/workflowTemplate:WorkflowTemplate": "WorkflowTemplate"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datastore/dataStoreIndex",
  "fqn": "pulumi_gcp.datastore",
  "classes": {
   "gcp:datastore/dataStoreIndex:DataStoreIndex": "DataStoreIndex"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datastream/connectionProfile",
  "fqn": "pulumi_gcp.datastream",
  "classes": {
   "gcp:datastream/connectionProfile:ConnectionProfile": "ConnectionProfile"
  }
 },
 {
  "pkg": "gcp",
  "mod": "datastream/privateConnection",
  "fqn": "pulumi_gcp.datastream",
  "classes": {
   "gcp:datastream/privateConnection:PrivateConnection": "PrivateConnection"
  }
 },
 {
  "pkg": "gcp",
  "mod": "deploymentmanager/deployment",
  "fqn": "pulumi_gcp.deploymentmanager",
  "classes": {
   "gcp:deploymentmanager/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/agent",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/agent:Agent": "Agent"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxAgent",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxAgent:CxAgent": "CxAgent"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxEntityType",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxEntityType:CxEntityType": "CxEntityType"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxEnvironment",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxEnvironment:CxEnvironment": "CxEnvironment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxFlow",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxFlow:CxFlow": "CxFlow"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxIntent",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxIntent:CxIntent": "CxIntent"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxPage",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxPage:CxPage": "CxPage"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxVersion",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxVersion:CxVersion": "CxVersion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/cxWebhook",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/cxWebhook:CxWebhook": "CxWebhook"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/entityType",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/entityType:EntityType": "EntityType"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/fulfillment",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/fulfillment:Fulfillment": "Fulfillment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "diagflow/intent",
  "fqn": "pulumi_gcp.diagflow",
  "classes": {
   "gcp:diagflow/intent:Intent": "Intent"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dns/managedZone",
  "fqn": "pulumi_gcp.dns",
  "classes": {
   "gcp:dns/managedZone:ManagedZone": "ManagedZone"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dns/policy",
  "fqn": "pulumi_gcp.dns",
  "classes": {
   "gcp:dns/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dns/recordSet",
  "fqn": "pulumi_gcp.dns",
  "classes": {
   "gcp:dns/recordSet:RecordSet": "RecordSet"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dns/responsePolicy",
  "fqn": "pulumi_gcp.dns",
  "classes": {
   "gcp:dns/responsePolicy:ResponsePolicy": "ResponsePolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "dns/responsePolicyRule",
  "fqn": "pulumi_gcp.dns",
  "classes": {
   "gcp:dns/responsePolicyRule:ResponsePolicyRule": "ResponsePolicyRule"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/consumersIamBinding",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/consumersIamBinding:ConsumersIamBinding": "ConsumersIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/consumersIamMember",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/consumersIamMember:ConsumersIamMember": "ConsumersIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/consumersIamPolicy",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/consumersIamPolicy:ConsumersIamPolicy": "ConsumersIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/service",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/service:Service": "Service"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/serviceIamBinding",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/serviceIamBinding:ServiceIamBinding": "ServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/serviceIamMember",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/serviceIamMember:ServiceIamMember": "ServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "endpoints/serviceIamPolicy",
  "fqn": "pulumi_gcp.endpoints",
  "classes": {
   "gcp:endpoints/serviceIamPolicy:ServiceIamPolicy": "ServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "essentialcontacts/contact",
  "fqn": "pulumi_gcp.essentialcontacts",
  "classes": {
   "gcp:essentialcontacts/contact:Contact": "Contact"
  }
 },
 {
  "pkg": "gcp",
  "mod": "essentialcontacts/documentAiProcessor",
  "fqn": "pulumi_gcp.essentialcontacts",
  "classes": {
   "gcp:essentialcontacts/documentAiProcessor:DocumentAiProcessor": "DocumentAiProcessor"
  }
 },
 {
  "pkg": "gcp",
  "mod": "essentialcontacts/documentAiProcessorDefaultVersion",
  "fqn": "pulumi_gcp.essentialcontacts",
  "classes": {
   "gcp:essentialcontacts/documentAiProcessorDefaultVersion:DocumentAiProcessorDefaultVersion": "DocumentAiProcessorDefaultVersion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "eventarc/trigger",
  "fqn": "pulumi_gcp.eventarc",
  "classes": {
   "gcp:eventarc/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "gcp",
  "mod": "filestore/instance",
  "fqn": "pulumi_gcp.filestore",
  "classes": {
   "gcp:filestore/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "filestore/snapshot",
  "fqn": "pulumi_gcp.filestore",
  "classes": {
   "gcp:filestore/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firebase/androidApp",
  "fqn": "pulumi_gcp.firebase",
  "classes": {
   "gcp:firebase/androidApp:AndroidApp": "AndroidApp"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firebase/project",
  "fqn": "pulumi_gcp.firebase",
  "classes": {
   "gcp:firebase/project:Project": "Project"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firebase/projectLocation",
  "fqn": "pulumi_gcp.firebase",
  "classes": {
   "gcp:firebase/projectLocation:ProjectLocation": "ProjectLocation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firebase/webApp",
  "fqn": "pulumi_gcp.firebase",
  "classes": {
   "gcp:firebase/webApp:WebApp": "WebApp"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firebaserules/release",
  "fqn": "pulumi_gcp.firebaserules",
  "classes": {
   "gcp:firebaserules/release:Release": "Release"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firebaserules/ruleset",
  "fqn": "pulumi_gcp.firebaserules",
  "classes": {
   "gcp:firebaserules/ruleset:Ruleset": "Ruleset"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firestore/document",
  "fqn": "pulumi_gcp.firestore",
  "classes": {
   "gcp:firestore/document:Document": "Document"
  }
 },
 {
  "pkg": "gcp",
  "mod": "firestore/index",
  "fqn": "pulumi_gcp.firestore",
  "classes": {
   "gcp:firestore/index:Index": "Index"
  }
 },
 {
  "pkg": "gcp",
  "mod": "folder/accessApprovalSettings",
  "fqn": "pulumi_gcp.folder",
  "classes": {
   "gcp:folder/accessApprovalSettings:AccessApprovalSettings": "AccessApprovalSettings"
  }
 },
 {
  "pkg": "gcp",
  "mod": "folder/iAMBinding",
  "fqn": "pulumi_gcp.folder",
  "classes": {
   "gcp:folder/iAMBinding:IAMBinding": "IAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "folder/iAMMember",
  "fqn": "pulumi_gcp.folder",
  "classes": {
   "gcp:folder/iAMMember:IAMMember": "IAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "folder/iAMPolicy",
  "fqn": "pulumi_gcp.folder",
  "classes": {
   "gcp:folder/iAMPolicy:IAMPolicy": "IAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "folder/iamAuditConfig",
  "fqn": "pulumi_gcp.folder",
  "classes": {
   "gcp:folder/iamAuditConfig:IamAuditConfig": "IamAuditConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "folder/organizationPolicy",
  "fqn": "pulumi_gcp.folder",
  "classes": {
   "gcp:folder/organizationPolicy:OrganizationPolicy": "OrganizationPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gameservices/gameServerCluster",
  "fqn": "pulumi_gcp.gameservices",
  "classes": {
   "gcp:gameservices/gameServerCluster:GameServerCluster": "GameServerCluster"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gameservices/gameServerConfig",
  "fqn": "pulumi_gcp.gameservices",
  "classes": {
   "gcp:gameservices/gameServerConfig:GameServerConfig": "GameServerConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gameservices/gameServerDeployment",
  "fqn": "pulumi_gcp.gameservices",
  "classes": {
   "gcp:gameservices/gameServerDeployment:GameServerDeployment": "GameServerDeployment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gameservices/gameServerDeploymentRollout",
  "fqn": "pulumi_gcp.gameservices",
  "classes": {
   "gcp:gameservices/gameServerDeploymentRollout:GameServerDeploymentRollout": "GameServerDeploymentRollout"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gameservices/realm",
  "fqn": "pulumi_gcp.gameservices",
  "classes": {
   "gcp:gameservices/realm:Realm": "Realm"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gkehub/feature",
  "fqn": "pulumi_gcp.gkehub",
  "classes": {
   "gcp:gkehub/feature:Feature": "Feature"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gkehub/featureMembership",
  "fqn": "pulumi_gcp.gkehub",
  "classes": {
   "gcp:gkehub/featureMembership:FeatureMembership": "FeatureMembership"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gkehub/membership",
  "fqn": "pulumi_gcp.gkehub",
  "classes": {
   "gcp:gkehub/membership:Membership": "Membership"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gkehub/membershipIamBinding",
  "fqn": "pulumi_gcp.gkehub",
  "classes": {
   "gcp:gkehub/membershipIamBinding:MembershipIamBinding": "MembershipIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gkehub/membershipIamMember",
  "fqn": "pulumi_gcp.gkehub",
  "classes": {
   "gcp:gkehub/membershipIamMember:MembershipIamMember": "MembershipIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "gkehub/membershipIamPolicy",
  "fqn": "pulumi_gcp.gkehub",
  "classes": {
   "gcp:gkehub/membershipIamPolicy:MembershipIamPolicy": "MembershipIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/consentStore",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/consentStore:ConsentStore": "ConsentStore"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/consentStoreIamBinding",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/consentStoreIamBinding:ConsentStoreIamBinding": "ConsentStoreIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/consentStoreIamMember",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/consentStoreIamMember:ConsentStoreIamMember": "ConsentStoreIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/consentStoreIamPolicy",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/consentStoreIamPolicy:ConsentStoreIamPolicy": "ConsentStoreIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/dataset",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/dataset:Dataset": "Dataset"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/datasetIamBinding",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/datasetIamBinding:DatasetIamBinding": "DatasetIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/datasetIamMember",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/datasetIamMember:DatasetIamMember": "DatasetIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/datasetIamPolicy",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/datasetIamPolicy:DatasetIamPolicy": "DatasetIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/dicomStore",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/dicomStore:DicomStore": "DicomStore"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/dicomStoreIamBinding",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/dicomStoreIamBinding:DicomStoreIamBinding": "DicomStoreIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/dicomStoreIamMember",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/dicomStoreIamMember:DicomStoreIamMember": "DicomStoreIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/dicomStoreIamPolicy",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/dicomStoreIamPolicy:DicomStoreIamPolicy": "DicomStoreIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/fhirStore",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/fhirStore:FhirStore": "FhirStore"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/fhirStoreIamBinding",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/fhirStoreIamBinding:FhirStoreIamBinding": "FhirStoreIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/fhirStoreIamMember",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/fhirStoreIamMember:FhirStoreIamMember": "FhirStoreIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/fhirStoreIamPolicy",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/fhirStoreIamPolicy:FhirStoreIamPolicy": "FhirStoreIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/hl7Store",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/hl7Store:Hl7Store": "Hl7Store"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/hl7StoreIamBinding",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/hl7StoreIamBinding:Hl7StoreIamBinding": "Hl7StoreIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/hl7StoreIamMember",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/hl7StoreIamMember:Hl7StoreIamMember": "Hl7StoreIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "healthcare/hl7StoreIamPolicy",
  "fqn": "pulumi_gcp.healthcare",
  "classes": {
   "gcp:healthcare/hl7StoreIamPolicy:Hl7StoreIamPolicy": "Hl7StoreIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iam/denyPolicy",
  "fqn": "pulumi_gcp.iam",
  "classes": {
   "gcp:iam/denyPolicy:DenyPolicy": "DenyPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iam/workforcePool",
  "fqn": "pulumi_gcp.iam",
  "classes": {
   "gcp:iam/workforcePool:WorkforcePool": "WorkforcePool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iam/workloadIdentityPool",
  "fqn": "pulumi_gcp.iam",
  "classes": {
   "gcp:iam/workloadIdentityPool:WorkloadIdentityPool": "WorkloadIdentityPool"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iam/workloadIdentityPoolProvider",
  "fqn": "pulumi_gcp.iam",
  "classes": {
   "gcp:iam/workloadIdentityPoolProvider:WorkloadIdentityPoolProvider": "WorkloadIdentityPoolProvider"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/appEngineServiceIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/appEngineServiceIamBinding:AppEngineServiceIamBinding": "AppEngineServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/appEngineServiceIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/appEngineServiceIamMember:AppEngineServiceIamMember": "AppEngineServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/appEngineServiceIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/appEngineServiceIamPolicy:AppEngineServiceIamPolicy": "AppEngineServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/appEngineVersionIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/appEngineVersionIamBinding:AppEngineVersionIamBinding": "AppEngineVersionIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/appEngineVersionIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/appEngineVersionIamMember:AppEngineVersionIamMember": "AppEngineVersionIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/appEngineVersionIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/appEngineVersionIamPolicy:AppEngineVersionIamPolicy": "AppEngineVersionIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/brand",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/brand:Brand": "Brand"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/client",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/client:Client": "Client"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/tunnelIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/tunnelIamBinding:TunnelIamBinding": "TunnelIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/tunnelIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/tunnelIamMember:TunnelIamMember": "TunnelIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/tunnelIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/tunnelIamPolicy:TunnelIamPolicy": "TunnelIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/tunnelInstanceIAMBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/tunnelInstanceIAMBinding:TunnelInstanceIAMBinding": "TunnelInstanceIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/tunnelInstanceIAMMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/tunnelInstanceIAMMember:TunnelInstanceIAMMember": "TunnelInstanceIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/tunnelInstanceIAMPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/tunnelInstanceIAMPolicy:TunnelInstanceIAMPolicy": "TunnelInstanceIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webBackendServiceIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webBackendServiceIamBinding:WebBackendServiceIamBinding": "WebBackendServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webBackendServiceIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webBackendServiceIamMember:WebBackendServiceIamMember": "WebBackendServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webBackendServiceIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webBackendServiceIamPolicy:WebBackendServiceIamPolicy": "WebBackendServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webIamBinding:WebIamBinding": "WebIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webIamMember:WebIamMember": "WebIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webIamPolicy:WebIamPolicy": "WebIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webTypeAppEngingIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webTypeAppEngingIamBinding:WebTypeAppEngingIamBinding": "WebTypeAppEngingIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webTypeAppEngingIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webTypeAppEngingIamMember:WebTypeAppEngingIamMember": "WebTypeAppEngingIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webTypeAppEngingIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webTypeAppEngingIamPolicy:WebTypeAppEngingIamPolicy": "WebTypeAppEngingIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webTypeComputeIamBinding",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webTypeComputeIamBinding:WebTypeComputeIamBinding": "WebTypeComputeIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webTypeComputeIamMember",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webTypeComputeIamMember:WebTypeComputeIamMember": "WebTypeComputeIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iap/webTypeComputeIamPolicy",
  "fqn": "pulumi_gcp.iap",
  "classes": {
   "gcp:iap/webTypeComputeIamPolicy:WebTypeComputeIamPolicy": "WebTypeComputeIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/config",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/config:Config": "Config"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/defaultSupportedIdpConfig",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/defaultSupportedIdpConfig:DefaultSupportedIdpConfig": "DefaultSupportedIdpConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/inboundSamlConfig",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/inboundSamlConfig:InboundSamlConfig": "InboundSamlConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/oauthIdpConfig",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/oauthIdpConfig:OauthIdpConfig": "OauthIdpConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/tenant",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/tenant:Tenant": "Tenant"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/tenantDefaultSupportedIdpConfig",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/tenantDefaultSupportedIdpConfig:TenantDefaultSupportedIdpConfig": "TenantDefaultSupportedIdpConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/tenantInboundSamlConfig",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/tenantInboundSamlConfig:TenantInboundSamlConfig": "TenantInboundSamlConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "identityplatform/tenantOauthIdpConfig",
  "fqn": "pulumi_gcp.identityplatform",
  "classes": {
   "gcp:identityplatform/tenantOauthIdpConfig:TenantOauthIdpConfig": "TenantOauthIdpConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iot/device",
  "fqn": "pulumi_gcp.iot",
  "classes": {
   "gcp:iot/device:Device": "Device"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iot/registry",
  "fqn": "pulumi_gcp.iot",
  "classes": {
   "gcp:iot/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iot/registryIamBinding",
  "fqn": "pulumi_gcp.iot",
  "classes": {
   "gcp:iot/registryIamBinding:RegistryIamBinding": "RegistryIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iot/registryIamMember",
  "fqn": "pulumi_gcp.iot",
  "classes": {
   "gcp:iot/registryIamMember:RegistryIamMember": "RegistryIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "iot/registryIamPolicy",
  "fqn": "pulumi_gcp.iot",
  "classes": {
   "gcp:iot/registryIamPolicy:RegistryIamPolicy": "RegistryIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/cryptoKey",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/cryptoKey:CryptoKey": "CryptoKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/cryptoKeyIAMBinding",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/cryptoKeyIAMBinding:CryptoKeyIAMBinding": "CryptoKeyIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/cryptoKeyIAMMember",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/cryptoKeyIAMMember:CryptoKeyIAMMember": "CryptoKeyIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/cryptoKeyIAMPolicy",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/cryptoKeyIAMPolicy:CryptoKeyIAMPolicy": "CryptoKeyIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/cryptoKeyVersion",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/cryptoKeyVersion:CryptoKeyVersion": "CryptoKeyVersion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/keyRing",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/keyRing:KeyRing": "KeyRing"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/keyRingIAMBinding",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/keyRingIAMBinding:KeyRingIAMBinding": "KeyRingIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/keyRingIAMMember",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/keyRingIAMMember:KeyRingIAMMember": "KeyRingIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/keyRingIAMPolicy",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/keyRingIAMPolicy:KeyRingIAMPolicy": "KeyRingIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/keyRingImportJob",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/keyRingImportJob:KeyRingImportJob": "KeyRingImportJob"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/registry",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/registry:Registry": "Registry"
  }
 },
 {
  "pkg": "gcp",
  "mod": "kms/secretCiphertext",
  "fqn": "pulumi_gcp.kms",
  "classes": {
   "gcp:kms/secretCiphertext:SecretCiphertext": "SecretCiphertext"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/billingAccountBucketConfig",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/billingAccountBucketConfig:BillingAccountBucketConfig": "BillingAccountBucketConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/billingAccountExclusion",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/billingAccountExclusion:BillingAccountExclusion": "BillingAccountExclusion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/billingAccountSink",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/billingAccountSink:BillingAccountSink": "BillingAccountSink"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/folderBucketConfig",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/folderBucketConfig:FolderBucketConfig": "FolderBucketConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/folderExclusion",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/folderExclusion:FolderExclusion": "FolderExclusion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/folderSink",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/folderSink:FolderSink": "FolderSink"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/logView",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/logView:LogView": "LogView"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/metric",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/metric:Metric": "Metric"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/organizationBucketConfig",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/organizationBucketConfig:OrganizationBucketConfig": "OrganizationBucketConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/organizationExclusion",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/organizationExclusion:OrganizationExclusion": "OrganizationExclusion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/organizationSink",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/organizationSink:OrganizationSink": "OrganizationSink"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/projectBucketConfig",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/projectBucketConfig:ProjectBucketConfig": "ProjectBucketConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/projectExclusion",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/projectExclusion:ProjectExclusion": "ProjectExclusion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "logging/projectSink",
  "fqn": "pulumi_gcp.logging",
  "classes": {
   "gcp:logging/projectSink:ProjectSink": "ProjectSink"
  }
 },
 {
  "pkg": "gcp",
  "mod": "memcache/instance",
  "fqn": "pulumi_gcp.memcache",
  "classes": {
   "gcp:memcache/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "ml/engineModel",
  "fqn": "pulumi_gcp.ml",
  "classes": {
   "gcp:ml/engineModel:EngineModel": "EngineModel"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/alertPolicy",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/alertPolicy:AlertPolicy": "AlertPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/customService",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/customService:CustomService": "CustomService"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/dashboard",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/genericService",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/genericService:GenericService": "GenericService"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/group",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/group:Group": "Group"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/metricDescriptor",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/metricDescriptor:MetricDescriptor": "MetricDescriptor"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/monitoredProject",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/monitoredProject:MonitoredProject": "MonitoredProject"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/notificationChannel",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/notificationChannel:NotificationChannel": "NotificationChannel"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/slo",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/slo:Slo": "Slo"
  }
 },
 {
  "pkg": "gcp",
  "mod": "monitoring/uptimeCheckConfig",
  "fqn": "pulumi_gcp.monitoring",
  "classes": {
   "gcp:monitoring/uptimeCheckConfig:UptimeCheckConfig": "UptimeCheckConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "networkconnectivity/hub",
  "fqn": "pulumi_gcp.networkconnectivity",
  "classes": {
   "gcp:networkconnectivity/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "gcp",
  "mod": "networkconnectivity/spoke",
  "fqn": "pulumi_gcp.networkconnectivity",
  "classes": {
   "gcp:networkconnectivity/spoke:Spoke": "Spoke"
  }
 },
 {
  "pkg": "gcp",
  "mod": "networkmanagement/connectivityTest",
  "fqn": "pulumi_gcp.networkmanagement",
  "classes": {
   "gcp:networkmanagement/connectivityTest:ConnectivityTest": "ConnectivityTest"
  }
 },
 {
  "pkg": "gcp",
  "mod": "networkservices/edgeCacheKeyset",
  "fqn": "pulumi_gcp.networkservices",
  "classes": {
   "gcp:networkservices/edgeCacheKeyset:EdgeCacheKeyset": "EdgeCacheKeyset"
  }
 },
 {
  "pkg": "gcp",
  "mod": "networkservices/edgeCacheOrigin",
  "fqn": "pulumi_gcp.networkservices",
  "classes": {
   "gcp:networkservices/edgeCacheOrigin:EdgeCacheOrigin": "EdgeCacheOrigin"
  }
 },
 {
  "pkg": "gcp",
  "mod": "networkservices/edgeCacheService",
  "fqn": "pulumi_gcp.networkservices",
  "classes": {
   "gcp:networkservices/edgeCacheService:EdgeCacheService": "EdgeCacheService"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/environment",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/instance",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/instanceIamBinding",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/instanceIamBinding:InstanceIamBinding": "InstanceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/instanceIamMember",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/instanceIamMember:InstanceIamMember": "InstanceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/instanceIamPolicy",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/instanceIamPolicy:InstanceIamPolicy": "InstanceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/location",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/location:Location": "Location"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/runtime",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/runtime:Runtime": "Runtime"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/runtimeIamBinding",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/runtimeIamBinding:RuntimeIamBinding": "RuntimeIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/runtimeIamMember",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/runtimeIamMember:RuntimeIamMember": "RuntimeIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "notebooks/runtimeIamPolicy",
  "fqn": "pulumi_gcp.notebooks",
  "classes": {
   "gcp:notebooks/runtimeIamPolicy:RuntimeIamPolicy": "RuntimeIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/accessApprovalSettings",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/accessApprovalSettings:AccessApprovalSettings": "AccessApprovalSettings"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/folder",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/folder:Folder": "Folder"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/iAMBinding",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/iAMBinding:IAMBinding": "IAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/iAMCustomRole",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/iAMCustomRole:IAMCustomRole": "IAMCustomRole"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/iAMMember",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/iAMMember:IAMMember": "IAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/iAMPolicy",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/iAMPolicy:IAMPolicy": "IAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/iamAuditConfig",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/iamAuditConfig:IamAuditConfig": "IamAuditConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/policy",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "organizations/project",
  "fqn": "pulumi_gcp.organizations",
  "classes": {
   "gcp:organizations/project:Project": "Project"
  }
 },
 {
  "pkg": "gcp",
  "mod": "orgpolicy/customConstraint",
  "fqn": "pulumi_gcp.orgpolicy",
  "classes": {
   "gcp:orgpolicy/customConstraint:CustomConstraint": "CustomConstraint"
  }
 },
 {
  "pkg": "gcp",
  "mod": "orgpolicy/policy",
  "fqn": "pulumi_gcp.orgpolicy",
  "classes": {
   "gcp:orgpolicy/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "osconfig/guestPolicies",
  "fqn": "pulumi_gcp.osconfig",
  "classes": {
   "gcp:osconfig/guestPolicies:GuestPolicies": "GuestPolicies"
  }
 },
 {
  "pkg": "gcp",
  "mod": "osconfig/osPolicyAssignment",
  "fqn": "pulumi_gcp.osconfig",
  "classes": {
   "gcp:osconfig/osPolicyAssignment:OsPolicyAssignment": "OsPolicyAssignment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "osconfig/patchDeployment",
  "fqn": "pulumi_gcp.osconfig",
  "classes": {
   "gcp:osconfig/patchDeployment:PatchDeployment": "PatchDeployment"
  }
 },
 {
  "pkg": "gcp",
  "mod": "oslogin/sshPublicKey",
  "fqn": "pulumi_gcp.oslogin",
  "classes": {
   "gcp:oslogin/sshPublicKey:SshPublicKey": "SshPublicKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/accessApprovalSettings",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/accessApprovalSettings:AccessApprovalSettings": "AccessApprovalSettings"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/apiKey",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/defaultServiceAccounts",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/defaultServiceAccounts:DefaultServiceAccounts": "DefaultServiceAccounts"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/iAMAuditConfig",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/iAMAuditConfig:IAMAuditConfig": "IAMAuditConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/iAMBinding",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/iAMBinding:IAMBinding": "IAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/iAMCustomRole",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/iAMCustomRole:IAMCustomRole": "IAMCustomRole"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/iAMMember",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/iAMMember:IAMMember": "IAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/iAMPolicy",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/iAMPolicy:IAMPolicy": "IAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/organizationPolicy",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/organizationPolicy:OrganizationPolicy": "OrganizationPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/service",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/service:Service": "Service"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/serviceIdentity",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/serviceIdentity:ServiceIdentity": "ServiceIdentity"
  }
 },
 {
  "pkg": "gcp",
  "mod": "projects/usageExportBucket",
  "fqn": "pulumi_gcp.projects",
  "classes": {
   "gcp:projects/usageExportBucket:UsageExportBucket": "UsageExportBucket"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/liteReservation",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/liteReservation:LiteReservation": "LiteReservation"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/liteSubscription",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/liteSubscription:LiteSubscription": "LiteSubscription"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/liteTopic",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/liteTopic:LiteTopic": "LiteTopic"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/schema",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/subscription",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/subscription:Subscription": "Subscription"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/subscriptionIAMBinding",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/subscriptionIAMBinding:SubscriptionIAMBinding": "SubscriptionIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/subscriptionIAMMember",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/subscriptionIAMMember:SubscriptionIAMMember": "SubscriptionIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/subscriptionIAMPolicy",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/subscriptionIAMPolicy:SubscriptionIAMPolicy": "SubscriptionIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/topic",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/topic:Topic": "Topic"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/topicIAMBinding",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/topicIAMBinding:TopicIAMBinding": "TopicIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/topicIAMMember",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/topicIAMMember:TopicIAMMember": "TopicIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "pubsub/topicIAMPolicy",
  "fqn": "pulumi_gcp.pubsub",
  "classes": {
   "gcp:pubsub/topicIAMPolicy:TopicIAMPolicy": "TopicIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "recaptcha/enterpriseKey",
  "fqn": "pulumi_gcp.recaptcha",
  "classes": {
   "gcp:recaptcha/enterpriseKey:EnterpriseKey": "EnterpriseKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "redis/instance",
  "fqn": "pulumi_gcp.redis",
  "classes": {
   "gcp:redis/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "resourcemanager/lien",
  "fqn": "pulumi_gcp.resourcemanager",
  "classes": {
   "gcp:resourcemanager/lien:Lien": "Lien"
  }
 },
 {
  "pkg": "gcp",
  "mod": "runtimeconfig/config",
  "fqn": "pulumi_gcp.runtimeconfig",
  "classes": {
   "gcp:runtimeconfig/config:Config": "Config"
  }
 },
 {
  "pkg": "gcp",
  "mod": "runtimeconfig/configIamBinding",
  "fqn": "pulumi_gcp.runtimeconfig",
  "classes": {
   "gcp:runtimeconfig/configIamBinding:ConfigIamBinding": "ConfigIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "runtimeconfig/configIamMember",
  "fqn": "pulumi_gcp.runtimeconfig",
  "classes": {
   "gcp:runtimeconfig/configIamMember:ConfigIamMember": "ConfigIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "runtimeconfig/configIamPolicy",
  "fqn": "pulumi_gcp.runtimeconfig",
  "classes": {
   "gcp:runtimeconfig/configIamPolicy:ConfigIamPolicy": "ConfigIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "runtimeconfig/variable",
  "fqn": "pulumi_gcp.runtimeconfig",
  "classes": {
   "gcp:runtimeconfig/variable:Variable": "Variable"
  }
 },
 {
  "pkg": "gcp",
  "mod": "secretmanager/secret",
  "fqn": "pulumi_gcp.secretmanager",
  "classes": {
   "gcp:secretmanager/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "gcp",
  "mod": "secretmanager/secretIamBinding",
  "fqn": "pulumi_gcp.secretmanager",
  "classes": {
   "gcp:secretmanager/secretIamBinding:SecretIamBinding": "SecretIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "secretmanager/secretIamMember",
  "fqn": "pulumi_gcp.secretmanager",
  "classes": {
   "gcp:secretmanager/secretIamMember:SecretIamMember": "SecretIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "secretmanager/secretIamPolicy",
  "fqn": "pulumi_gcp.secretmanager",
  "classes": {
   "gcp:secretmanager/secretIamPolicy:SecretIamPolicy": "SecretIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "secretmanager/secretVersion",
  "fqn": "pulumi_gcp.secretmanager",
  "classes": {
   "gcp:secretmanager/secretVersion:SecretVersion": "SecretVersion"
  }
 },
 {
  "pkg": "gcp",
  "mod": "securitycenter/notificationConfig",
  "fqn": "pulumi_gcp.securitycenter",
  "classes": {
   "gcp:securitycenter/notificationConfig:NotificationConfig": "NotificationConfig"
  }
 },
 {
  "pkg": "gcp",
  "mod": "securitycenter/source",
  "fqn": "pulumi_gcp.securitycenter",
  "classes": {
   "gcp:securitycenter/source:Source": "Source"
  }
 },
 {
  "pkg": "gcp",
  "mod": "securitycenter/sourceIamBinding",
  "fqn": "pulumi_gcp.securitycenter",
  "classes": {
   "gcp:securitycenter/sourceIamBinding:SourceIamBinding": "SourceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "securitycenter/sourceIamMember",
  "fqn": "pulumi_gcp.securitycenter",
  "classes": {
   "gcp:securitycenter/sourceIamMember:SourceIamMember": "SourceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "securitycenter/sourceIamPolicy",
  "fqn": "pulumi_gcp.securitycenter",
  "classes": {
   "gcp:securitycenter/sourceIamPolicy:SourceIamPolicy": "SourceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "serviceAccount/account",
  "fqn": "pulumi_gcp.serviceaccount",
  "classes": {
   "gcp:serviceAccount/account:Account": "Account"
  }
 },
 {
  "pkg": "gcp",
  "mod": "serviceAccount/iAMBinding",
  "fqn": "pulumi_gcp.serviceaccount",
  "classes": {
   "gcp:serviceAccount/iAMBinding:IAMBinding": "IAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "serviceAccount/iAMMember",
  "fqn": "pulumi_gcp.serviceaccount",
  "classes": {
   "gcp:serviceAccount/iAMMember:IAMMember": "IAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "serviceAccount/iAMPolicy",
  "fqn": "pulumi_gcp.serviceaccount",
  "classes": {
   "gcp:serviceAccount/iAMPolicy:IAMPolicy": "IAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "serviceAccount/key",
  "fqn": "pulumi_gcp.serviceaccount",
  "classes": {
   "gcp:serviceAccount/key:Key": "Key"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/endpoint",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/namespace",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/namespaceIamBinding",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/namespaceIamBinding:NamespaceIamBinding": "NamespaceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/namespaceIamMember",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/namespaceIamMember:NamespaceIamMember": "NamespaceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/namespaceIamPolicy",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/namespaceIamPolicy:NamespaceIamPolicy": "NamespaceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/service",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/service:Service": "Service"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/serviceIamBinding",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/serviceIamBinding:ServiceIamBinding": "ServiceIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/serviceIamMember",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/serviceIamMember:ServiceIamMember": "ServiceIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicedirectory/serviceIamPolicy",
  "fqn": "pulumi_gcp.servicedirectory",
  "classes": {
   "gcp:servicedirectory/serviceIamPolicy:ServiceIamPolicy": "ServiceIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicenetworking/connection",
  "fqn": "pulumi_gcp.servicenetworking",
  "classes": {
   "gcp:servicenetworking/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "gcp",
  "mod": "servicenetworking/peeredDnsDomain",
  "fqn": "pulumi_gcp.servicenetworking",
  "classes": {
   "gcp:servicenetworking/peeredDnsDomain:PeeredDnsDomain": "PeeredDnsDomain"
  }
 },
 {
  "pkg": "gcp",
  "mod": "serviceusage/consumerQuotaOverride",
  "fqn": "pulumi_gcp.serviceusage",
  "classes": {
   "gcp:serviceusage/consumerQuotaOverride:ConsumerQuotaOverride": "ConsumerQuotaOverride"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sourcerepo/repository",
  "fqn": "pulumi_gcp.sourcerepo",
  "classes": {
   "gcp:sourcerepo/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sourcerepo/repositoryIamBinding",
  "fqn": "pulumi_gcp.sourcerepo",
  "classes": {
   "gcp:sourcerepo/repositoryIamBinding:RepositoryIamBinding": "RepositoryIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sourcerepo/repositoryIamMember",
  "fqn": "pulumi_gcp.sourcerepo",
  "classes": {
   "gcp:sourcerepo/repositoryIamMember:RepositoryIamMember": "RepositoryIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sourcerepo/repositoryIamPolicy",
  "fqn": "pulumi_gcp.sourcerepo",
  "classes": {
   "gcp:sourcerepo/repositoryIamPolicy:RepositoryIamPolicy": "RepositoryIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/database",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/database:Database": "Database"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/databaseIAMBinding",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/databaseIAMBinding:DatabaseIAMBinding": "DatabaseIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/databaseIAMMember",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/databaseIAMMember:DatabaseIAMMember": "DatabaseIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/databaseIAMPolicy",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/databaseIAMPolicy:DatabaseIAMPolicy": "DatabaseIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/instance",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/instanceIAMBinding",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/instanceIAMBinding:InstanceIAMBinding": "InstanceIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/instanceIAMMember",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/instanceIAMMember:InstanceIAMMember": "InstanceIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "spanner/instanceIAMPolicy",
  "fqn": "pulumi_gcp.spanner",
  "classes": {
   "gcp:spanner/instanceIAMPolicy:InstanceIAMPolicy": "InstanceIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sql/database",
  "fqn": "pulumi_gcp.sql",
  "classes": {
   "gcp:sql/database:Database": "Database"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sql/databaseInstance",
  "fqn": "pulumi_gcp.sql",
  "classes": {
   "gcp:sql/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sql/sourceRepresentationInstance",
  "fqn": "pulumi_gcp.sql",
  "classes": {
   "gcp:sql/sourceRepresentationInstance:SourceRepresentationInstance": "SourceRepresentationInstance"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sql/sslCert",
  "fqn": "pulumi_gcp.sql",
  "classes": {
   "gcp:sql/sslCert:SslCert": "SslCert"
  }
 },
 {
  "pkg": "gcp",
  "mod": "sql/user",
  "fqn": "pulumi_gcp.sql",
  "classes": {
   "gcp:sql/user:User": "User"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucket",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucketACL",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucketACL:BucketACL": "BucketACL"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucketAccessControl",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucketAccessControl:BucketAccessControl": "BucketAccessControl"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucketIAMBinding",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucketIAMBinding:BucketIAMBinding": "BucketIAMBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucketIAMMember",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucketIAMMember:BucketIAMMember": "BucketIAMMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucketIAMPolicy",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucketIAMPolicy:BucketIAMPolicy": "BucketIAMPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/bucketObject",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/bucketObject:BucketObject": "BucketObject"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/defaultObjectACL",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/defaultObjectACL:DefaultObjectACL": "DefaultObjectACL"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/defaultObjectAccessControl",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/defaultObjectAccessControl:DefaultObjectAccessControl": "DefaultObjectAccessControl"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/hmacKey",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/hmacKey:HmacKey": "HmacKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/notification",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/notification:Notification": "Notification"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/objectACL",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/objectACL:ObjectACL": "ObjectACL"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/objectAccessControl",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/objectAccessControl:ObjectAccessControl": "ObjectAccessControl"
  }
 },
 {
  "pkg": "gcp",
  "mod": "storage/transferJob",
  "fqn": "pulumi_gcp.storage",
  "classes": {
   "gcp:storage/transferJob:TransferJob": "TransferJob"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagBinding",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagBinding:TagBinding": "TagBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagKey",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagKey:TagKey": "TagKey"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagKeyIamBinding",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagKeyIamBinding:TagKeyIamBinding": "TagKeyIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagKeyIamMember",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagKeyIamMember:TagKeyIamMember": "TagKeyIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagKeyIamPolicy",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagKeyIamPolicy:TagKeyIamPolicy": "TagKeyIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagValue",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagValue:TagValue": "TagValue"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagValueIamBinding",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagValueIamBinding:TagValueIamBinding": "TagValueIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagValueIamMember",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagValueIamMember:TagValueIamMember": "TagValueIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tags/tagValueIamPolicy",
  "fqn": "pulumi_gcp.tags",
  "classes": {
   "gcp:tags/tagValueIamPolicy:TagValueIamPolicy": "TagValueIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "tpu/node",
  "fqn": "pulumi_gcp.tpu",
  "classes": {
   "gcp:tpu/node:Node": "Node"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiDataset",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiDataset:AiDataset": "AiDataset"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiEndpoint",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiEndpoint:AiEndpoint": "AiEndpoint"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiFeatureStore",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiFeatureStore:AiFeatureStore": "AiFeatureStore"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiFeatureStoreEntityType",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiFeatureStoreEntityType:AiFeatureStoreEntityType": "AiFeatureStoreEntityType"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiFeatureStoreEntityTypeFeature",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiFeatureStoreEntityTypeFeature:AiFeatureStoreEntityTypeFeature": "AiFeatureStoreEntityTypeFeature"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiFeatureStoreIamBinding",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiFeatureStoreIamBinding:AiFeatureStoreIamBinding": "AiFeatureStoreIamBinding"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiFeatureStoreIamMember",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiFeatureStoreIamMember:AiFeatureStoreIamMember": "AiFeatureStoreIamMember"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiFeatureStoreIamPolicy",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiFeatureStoreIamPolicy:AiFeatureStoreIamPolicy": "AiFeatureStoreIamPolicy"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vertex/aiMetadataStore",
  "fqn": "pulumi_gcp.vertex",
  "classes": {
   "gcp:vertex/aiMetadataStore:AiMetadataStore": "AiMetadataStore"
  }
 },
 {
  "pkg": "gcp",
  "mod": "vpcaccess/connector",
  "fqn": "pulumi_gcp.vpcaccess",
  "classes": {
   "gcp:vpcaccess/connector:Connector": "Connector"
  }
 },
 {
  "pkg": "gcp",
  "mod": "workflows/workflow",
  "fqn": "pulumi_gcp.workflows",
  "classes": {
   "gcp:workflows/workflow:Workflow": "Workflow"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "gcp",
  "token": "pulumi:providers:gcp",
  "fqn": "pulumi_gcp",
  "class": "Provider"
 }
]
"""
)
